# Generated by roxygen2: do not edit by hand

export(calculate_Rhat)
export(calculate_SUCRA_MNBT)
export(clusterplot_ranks)
export(cumulativeprobplot_ranks)
export(fit_raceNMA)
export(forestplot_muhat)
export(mcmc_raceNMA)
export(sample_partition_correlation)
export(sample_partition_independence)
export(traceplot_K)
export(traceplot_mu)
import(coda)
import(dplyr)
import(ggplot2)
import(invgamma)
import(mvtnorm)
import(reshape2)
import(utils)
importFrom(dplyr,filter)
importFrom(dplyr,select)
importFrom(magrittr,"%>%")
importFrom(stats,dnorm)
importFrom(stats,na.exclude)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,var)
