RaCE.NMA
-----

The ``RaCE.NMA`` R package implements the the Rank-Clustering Estimation model for Network Meta-Analysis (RaCE-NMA) proposed by [Pearce and Zhou (2025)](https://doi.org/10.1017/rsm.2025.10049).

Where can I learn more? 
-----

To learn more about the methodology implemented by this package, check out our [paper](https://doi.org/10.1017/rsm.2025.10049) in the journal *Research Synthesis Methods*.

For instructions on downloading the `RaCE.NMA` R package from Github, see the [Overview](https://pearce790.github.io/RaCE.NMA/articles/overview.html) tab. 

After downloading, check out the following articles:

  + [Tutorial](https://pearce790.github.io/RaCE.NMA/articles/tutorial.html) for examples of how to use the package's key R functions.
  + [Reproducibility](https://pearce790.github.io/RaCE.NMA/articles/reproducibility.html) for code to replicate the paper.
  + [Reference](https://pearce790.github.io/rankclust/reference/index.html) for a list of functions and links to associated documentation.

Acknowledgements and Funding
-----

This project is partially supported by NIH Grant R21LM014534. The content is solely the responsibility of the authors and does not necessarily represent the official views of the National Institutes of Health.
