#' Posterior relative treatment effects for non-baseline treatments based on Wang et. al (2022)
#'
#' The dataset includes relative treatment effects for 10 non-baseline treatments across 60k posterior
#' draws based on an NMA study by Wang et. al (2022).
#'
#' @format data.frame in which the (i,j) entry is the relative treatment effect of treatment j in posterior draw i.
"wang_posterior"
