#' Toy data of posterior relative treatment effects
#'
#' The dataset includes relative treatment effects for 4 treatments across 10k posterior
#' draws, as studied in Simulation Study 2 of Pearce and Zhou (2025).
#'
#' @format data.frame in which the (i,j) entry is the relative treatment effect of treatment j in posterior draw i.
"toy_data"
