% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/forestplot_muhat.R
\name{forestplot_muhat}
\alias{forestplot_muhat}
\title{Create posterior forest plots for relative treatment effect estimates from a standard or RaCE NMA study}
\usage{
forestplot_muhat(
  data = NULL,
  mcmc = NULL,
  names = NULL,
  level = 0.95,
  order_by_average = TRUE
)
}
\arguments{
\item{data}{A NxJ matrix of data to display as a forest plot, where N is the number of observations and J the number of treatments. This feature is designed for use to display a forest plot of results from a standard NMA study.}

\item{mcmc}{MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.}

\item{names}{A vector of intervention names (optional)}

\item{level}{A numeric indicating the desired credible level to be displayed, as a proportion. Defaults to 0.95.}

\item{order_by_average}{A boolean indicating if plot should order treatments by their average treatment effect.}
}
\value{
A ggplot of posterior forest plots for the mu parameter.
}
\description{
This function creates posterior forest plots for relative treatment effect estimates from a standard or RaCE NMA study.
}
\examples{
data("toy_data")
forestplot_muhat(data=toy_data,names=paste0("Treatment ",1:4))
}
