% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calculate_SUCRA_MNBT.R
\name{calculate_SUCRA_MNBT}
\alias{calculate_SUCRA_MNBT}
\title{Calculate SUCRA and MNBT based on MCMC draws in NMA or RaCE-NMA models}
\usage{
calculate_SUCRA_MNBT(data = NULL, mcmc = NULL, level = 0.5, names = NULL)
}
\arguments{
\item{data}{A NxJ matrix of data, where N is the number of observations and J the number of treatments. This feature is designed to display results from a standard NMA study.}

\item{mcmc}{MCMC draws from the RaCE NMA model, in the form of the model output of the \code{mcmc_RCMVN} function.}

\item{level}{The \code{level} level for the interval estimate of MNBT. Defaults to 0.50.}

\item{names}{A vector of intervention names (optional)}
}
\value{
A table containing SUCRA and MNBT values for each treatment, ordered by descending SUCRA values.
}
\description{
This function creates a results table of SUCRA and Median Number of Better Treatments (MNBT) based on
MCMC draws from a standard NMA model or a fitted RaCE-NMA model.
}
\examples{
mcmc <- mcmc_raceNMA(mu_hat=c(0,0,1,1), s=c(.1,.1,.1,.1), seed=1)
calculate_SUCRA_MNBT(mcmc=mcmc)
}
